"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Endpoints_1 = require("../Endpoints");
const APIBase_1 = require("./APIBase");
class ProjectAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * Get information about a package and it's versions.
     * @see https://libraries.io/api#project
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getProject(platform, projectName) {
        const endpoint = Endpoints_1.Endpoint.Project.project(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Get a list of dependencies for a version of a project, pass `latest` as version to get dependency info for the latest available version
     * @see https://libraries.io/api#project-dependencies
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param projectVersion
     */
    getProjectWithDependencies(platform, projectName, projectVersion) {
        const endpoint = Endpoints_1.Endpoint.Project.dependencies(platform, projectName, projectVersion);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Get packages that have at least one version that depends on a given project.
     * @see https://libraries.io/api#project-dependents
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getDependendents(platform, projectName, options) {
        const endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get repositories that depend on a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getDependendentRepositories(platform, projectName, options) {
        const endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get users that have contributed to a given project.
     * @see https://libraries.io/api#project-contributors
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getContributors(platform, projectName, options) {
        const endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get breakdown of SourceRank score for a given project.
     * @see https://libraries.io/api#project-sourcerank
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getSourceRank(platform, projectName) {
        const endpoint = Endpoints_1.Endpoint.Project.sourceRank(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Get breakdown of version usage for a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getUsage(platform, projectName) {
        const endpoint = Endpoints_1.Endpoint.Project.sourceRank(platform, projectName);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Search for projects.
     * @see https://libraries.io/api#project-search
     * @param query The search query
     * @param options Sorting, filter and pagination options
     */
    search(query, options) {
        const endpoint = Endpoints_1.Endpoint.Project.search();
        return this.apiClient.requestService.get(endpoint, { data: Object.assign({}, options, { q: query }) });
    }
}
exports.ProjectAPI = ProjectAPI;
//# sourceMappingURL=ProjectAPI.js.map